/**
 * Represents the handle of an initialized Svelte Action
 */
export interface IActionHandle<T = any> {
    /**
     * Destroys all bindings the Action was using
     */
    destroy?: () => void;
    /**
     * Replaces the options that was initially passed to the Action
     */
    update?: (options: T) => void;
}
/**
 * Represents the constructor of a Svelte Action
 */
export declare type IAction<NodeType extends Node, OptionsType = any, HandleType extends IActionHandle = IActionHandle<OptionsType>> = (node: NodeType, options: OptionsType) => HandleType;
/**
 * Represents the Svelte Action initializer signature for [[forward_actions]]
 */
export declare type IForwardActionsAction = IAction<Node, IForwardActionsOptions, IForwardActionsHandle>;
/**
 * Represents the Svelte Action handle returned by [[forward_actions]]
 */
export declare type IForwardActionsHandle = Required<IActionHandle<IForwardActionsOptions>>;
/**
 * Represents an array of forwarded Svelte Actions, optionally
 * associated with their options
 */
export declare type IForwardedActions = (IAction<any> | [IAction<any>, any])[];
/**
 * Represents the options passable to the [[forward_actions]] Svelte Action
 */
export interface IForwardActionsOptions {
    /**
     * Represents Svelte Actions that will be attached to the targeted element
     */
    actions?: IForwardedActions;
}
/**
 * Attaches the provided array of Svelte Actions to the target element, handling
 * lifecycle events automatically
 *
 * @param node
 * @param options
 * @returns
 */
export declare const forward_actions: IForwardActionsAction;
